# perceptron_package


References -
https://packaging.python.org/en/latest/tutorials/packaging-projects/


pypi package successfully posted- pip install perceptron-pkg-deftydev==0.0.3

![image](https://user-images.githubusercontent.com/58273709/226369103-2927cc44-d403-4abf-a010-ccd101cd9c46.png)
